@@ -29,7 +29,7 @@ except NameError: # pragma no cover
     _unicode = str
 
 __author__ = 'Martin Blech'
-__version__ = '0.5.1'
+__version__ = '0.7.0'
 __license__ = 'MIT'
 
 class ParsingInterrupted(Exception): pass
@@ -45,7 +45,9 @@ class _DictSAXHandler(object):
                  cdata_separator='',
                  postprocessor=None,
                  dict_constructor=OrderedDict,
-                 strip_whitespace=True):
+                 strip_whitespace=True,
+                 namespace_separator=':',
+                 namespaces=None):
         self.path = []
         self.stack = []
         self.data = None
@@ -60,8 +62,24 @@ class _DictSAXHandler(object):
         self.postprocessor = postprocessor
         self.dict_constructor = dict_constructor
         self.strip_whitespace = strip_whitespace
+        self.namespace_separator = namespace_separator
+        self.namespaces = namespaces
 
-    def startElement(self, name, attrs):
+    def _build_name(self, full_name):
+        if not self.namespaces:
+            return full_name
+        i = full_name.rfind(self.namespace_separator)
+        if i == -1:
+            return full_name
+        namespace, name = full_name[:i], full_name[i+1:]
+        short_namespace = self.namespaces.get(namespace, namespace)
+        if not short_namespace:
+            return name
+        else:
+            return self.namespace_separator.join((short_namespace, name))
+
+    def startElement(self, full_name, attrs):
+        name = self._build_name(full_name)
         attrs = self.dict_constructor(zip(attrs[0::2], attrs[1::2]))
         self.path.append((name, attrs or None))
         if len(self.path) > self.item_depth:
@@ -75,7 +93,8 @@ class _DictSAXHandler(object):
             self.item = attrs or None
             self.data = None
 
-    def endElement(self, name):
+    def endElement(self, full_name):
+        name = self._build_name(full_name)
         if len(self.path) == self.item_depth:
             item = self.item
             if item is None:
@@ -124,7 +143,8 @@ class _DictSAXHandler(object):
             item[key] = data
         return item
 
-def parse(xml_input, encoding='utf-8', expat=expat, *args, **kwargs):
+def parse(xml_input, encoding='utf-8', expat=expat, process_namespaces=False,
+          namespace_separator=':', **kwargs):
     """Parse the given XML input and convert it into a dictionary.
 
     `xml_input` can either be a `string` or a file-like object.
@@ -191,8 +211,11 @@ def parse(xml_input, encoding='utf-8', expat=expat, *args, **kwargs):
         OrderedDict([(u'a', u'hello')])
 
     """
-    handler = _DictSAXHandler(*args, **kwargs)
-    parser = expat.ParserCreate()
+    handler = _DictSAXHandler(namespace_separator=namespace_separator, **kwargs)
+    parser = expat.ParserCreate(
+        encoding,
+        namespace_separator if process_namespaces else None
+    )
     parser.ordered_attributes = True
     parser.StartElementHandler = handler.startElement
     parser.EndElementHandler = handler.endElement
@@ -208,8 +231,11 @@ def parse(xml_input, encoding='utf-8', expat=expat, *args, **kwargs):
 def _emit(key, value, content_handler,
           attr_prefix='@',
           cdata_key='#text',
-          root=True,
-          preprocessor=None):
+          depth=0,
+          preprocessor=None,
+          pretty=False,
+          newl='\n',
+          indent='\t'):
     if preprocessor is not None:
         result = preprocessor(key, value)
         if result is None:
@@ -217,7 +243,7 @@ def _emit(key, value, content_handler,
         key, value = result
     if not isinstance(value, (list, tuple)):
         value = [value]
-    if root and len(value) > 1:
+    if depth == 0 and len(value) > 1:
         raise ValueError('document with multiple roots')
     for v in value:
         if v is None:
@@ -237,16 +263,35 @@ def _emit(key, value, content_handler,
                 attrs[ik[len(attr_prefix):]] = iv
                 continue
             children.append((ik, iv))
+        if pretty and depth:
+            content_handler.ignorableWhitespace(newl + indent * depth)
         content_handler.startElement(key, AttributesImpl(attrs))
         for child_key, child_value in children:
             _emit(child_key, child_value, content_handler,
-                  attr_prefix, cdata_key, False, preprocessor)
+                  attr_prefix, cdata_key, depth+1, preprocessor,
+                  pretty, newl, indent)
         if cdata is not None:
             content_handler.characters(cdata)
         content_handler.endElement(key)
+        if pretty and depth:
+            content_handler.ignorableWhitespace(newl + indent * (depth - 1))
 
-def unparse(item, output=None, encoding='utf-8', **kwargs):
-    ((key, value),) = item.items()
+def unparse(input_dict, output=None, encoding='utf-8', **kwargs):
+    """Emit an XML document for the given `input_dict` (reverse of `parse`).
+
+    The resulting XML document is returned as a string, but if `output` (a
+    file-like object) is specified, it is written there instead.
+
+    Dictionary keys prefixed with `attr_prefix` (default=`'@'`) are interpreted
+    as XML node attributes, whereas keys equal to `cdata_key`
+    (default=`'#text'`) are treated as character data.
+
+    The `pretty` parameter (default=`False`) enables pretty-printing. In this
+    mode, lines are terminated with `'\n'` and indented with `'\t'`, but this
+    can be customized with the `newl` and `indent` parameters.
+
+    """
+    ((key, value),) = input_dict.items()
     must_return = False
     if output == None:
         output = StringIO()
